% Sovitetaan m-tiedoston 'nlsq' malli dataan (t,y)
% Alkuarvaus:
a0 = [1 1 1 1 1 1];
% Haetaan optimi rutiinilla 'leastsq':
[res, opt] = leastsq('nlsq',a0,[],[],t,y)
% Lasketaan mallin ja datan erotuksen neliosumma:
diff = sum(nlsq(res,t,y).^2);
% Piirretaan kuva:
tr = -1.5:0.05:1.5;
plot(t,y,'x',tr,nlfun(res,tr),'-')
