      implicit none
      integer n, nsuc, iprint, nfev, iout
      parameter (n = 2)
      double precision x0(n), xmin(2), fmin
      data x0 / 0.0d0, 0.0d0 /
      nsuc = 3
      iprint = 0
      call sigma1(n,x0,nsuc,iprint,xmin,fmin,nfev,iout)
      stop
      end
c                     Kohdefunktio
      double precision function funct (n,x)
      double precision x(n)
      funct = - 3*(1-x(1))**2*exp(-(x(1)**2) - (x(2)+1)**2)
     %     + 10*(x(1)/5 - x(1)**3 - x(2)**5)*exp(-x(1)**2-x(2)**2) 
     %     + 1/3*exp(-(x(1)+1)**2 - x(2)**2)
      return
      end
