Grad[f_,var_List] := D[f, #]& /@ var;

Div[F_List, var_list] := Inner[D, F, var, Plus];

Lap[f_, var_List] := Div[Grad[f, var], var];

Hesse[f_, var_List] := Outer[D, Grad[f, var], var];

Jac[F_List, var_List] := Outer[D, F, var];
